@@ -341,12 +341,12 @@ class accuinsight(object):
                 delta_ts = end_ts - start_ts
 
                 clear_runs(start_ts, end_ts, delta_ts)
-#                 accuinsight._send_message(metric=self.monitor,
-#                                           current_value=self.current_value,
-#                                           message=message,
-#                                           thresholds=thresholds,
-#                                           token=token,
-#                                           channel_id=channel_id)
+                accuinsight._send_message(metric=self.monitor,
+                                          current_value=self.current_value,
+                                          message=self.message,
+                                          thresholds=self.thresholds,
+                                          token=self.token,
+                                          channel_id=self.channel_id)
                 modeler_rest = LifecycleRestApi(LcConst.BACK_END_API_URL,
                                                 LcConst.BACK_END_API_PORT,
                                                 LcConst.BACK_END_API_URI)
