@@ -21,6 +21,7 @@ RUN_OBJ_NAME = 'run_name'
 RUN_OBJ_JSON_PATH = 'json_path'
 RUN_OBJ_CSV_PATH = 'csv_path'
 RUN_OBJ_VISUAL_PATH = 'visual_path'
+RUN_OBJ_SHAP_PATH = 'shap_path'
 
 # path for setting
 RUN_OBJ_MODEL_FILE_PATH = 'path'
@@ -36,8 +37,8 @@ RUN_OBJ_DATA_VERSION = 'data_version'
 # full path
 RUN_MODEL_JSON_PATH = 'model_json_full'
 RUN_MODEL_VISUAL_JSON_PATH = 'visual_json_full'
-RUN_MODEL_VISUAL_CSV_PATH = 'visual_csv_full'
 RUN_MODEL_SHAP_JSON_PATH = 'shap_json_full'
+RUN_MODEL_VISUAL_CSV_PATH = 'visual_csv_full'
 RUN_MODEL_HDF5_PATH = 'save_model_hdf5'
 RUN_MODEL_HOME_PATH = 'home_path'
 RUN_RESULT_PATH = 'result_path'
@@ -65,9 +66,15 @@ ENV_USER_SSO_ID = 'LC_USER_SSO_ID'
 ENV_LANGUAGE_ID = 'LC_LANGUAGE_ID'
 
 ENV_JUPYTER_WORKSPACE = '/home/notebook/.jupyter/lab/workspaces'
-ENV_JUPYTER__HOME_DIR = '/home/work'
+ENV_JUPYTER_HOME_DIR = '/home/work'
+
+DB_CONNECT_USER = 'modeler'
+DB_CONNECT_PASSWD = '!Modeleradmin1234'
+DB_CONNECT_HOST = 'accuinsight.mariadb.database.azure.com'
+DB_CONNECT_PORT = 3306
+DB_CONNECT_DB = 'modeler'
+DB_CONNECT_CHARSET = 'utf8'
 
 BACK_END_API_URI = ''
-BACK_END_API_URL = 'modeler-api.accu'
+BACK_END_API_URL = 'api.accu'
 BACK_END_API_PORT = '8080'
-
