@@ -61,28 +61,19 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
     ## 모델별 path 구성
     json_path_model = 'model-info-json'     # 기본적인 모형 관련 정보가 저장되는 json_path(ML/DL 공통)
     json_path_visual = 'for-visual-json'    # classification일 경우, json_path 하나 더 생성됨
-
+    json_path_shap = 'shap-value-json'      # shap_value(feature_contribution) json 파일 저장하는 path(ML/DL 공통)
 
     if 'keras' in get.model_type(model_name) or 'tf' in get.model_type(model_name) or 'pytorch' in get.model_type(model_name):
         csv_path_visual = 'for-visual-csv'            # learning history가 저장되는 csv_path
 
-#         # make dir 'best_model'
-#         save_best_model = 'best-model' # train 중 가장 좋은 모델의 weight 정보 저장
-
-#         if not os.path.isdir(home + save_best_model):
-#             try:
-#                 os.mkdir(home + save_best_model)
-#             except:
-#                 pass
-
-        path_list = [json_path_model, csv_path_visual, json_path_visual]   # DL
+        path_list = [json_path_model, csv_path_visual, json_path_visual, json_path_shap]   # DL
 
 
     elif 'Classifier' in get.model_type(model_name) or 'Logistic' in get.model_type(model_name) or 'SVC' in get.model_type(model_name) or 'NB' in get.model_type(model_name):
-        path_list = [json_path_model, json_path_visual]                       # ML & Classification
+        path_list = [json_path_model, json_path_visual, json_path_shap]       # ML & Classification
 
     else:
-        path_list = [json_path_model]                                         # DL & Regression
+        path_list = [json_path_model, json_path_shap]                         # ML & Regression
     
     for j in [i for i in path_list if not os.path.isdir(i)]:
         try:
@@ -104,18 +95,22 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
         trial_num = str(max(trial_num_list))
     
     ## 최종 path
-    if len(path_list) == 1:     # ML & Regression
+    if len(path_list) == 2:     # ML & Regression
         json_file_name_model = json_path_model + '/' + get.model_type(model_name) + '-' + trial_num + '.json'
+        json_file_name_shap = json_path_shap + '/' + get.model_type(model_name) + '-shap-' + trial_num + '.json'
         dir_dict = {'home_path': home,
                     'prefix_path': prefix_path,
                     'save_model_dir': save_best_model,
                     'save_model_joblib': save_model_path,
                     'model_json': json_file_name_model,
-                    'model_json_full': home + prefix_path + json_file_name_model}
+                    'shap_json': json_file_name_shap,
+                    'model_json_full': home + prefix_path + json_file_name_model,
+                    'shap_json_full': home + prefix_path + json_file_name_shap}
 
     elif 'json' in path_list[1]: # ML & Classification
         json_file_name_model = json_path_model + '/' + get.model_type(model_name) + '-' + trial_num + '.json'
         json_file_name_visual = json_path_visual + '/' + get.model_type(model_name) + '-visual-' + trial_num + '.json'
+        json_file_name_shap = json_path_shap + '/' + get.model_type(model_name) + '-shap-' + trial_num + '.json'
 
         dir_dict = {'home_path': home,
                     'prefix_path': prefix_path,
@@ -123,14 +118,16 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
                     'save_model_joblib': save_model_path,
                     'model_json': json_file_name_model,
                     'visual_json': json_file_name_visual,
+                    'shap_json': json_file_name_shap,
                     'model_json_full': home + prefix_path + json_file_name_model,
-                    'visual_json_full': home + prefix_path + json_file_name_visual}
+                    'visual_json_full': home + prefix_path + json_file_name_visual,
+                    'shap_json_full': home + prefix_path + json_file_name_shap}
 
-    elif len(path_list) == 3: # DL
+    elif len(path_list) == 4: # DL
         csv_file_name_visual = csv_path_visual + '/' + get.model_type(model_name) + '-history-' + trial_num + '.csv'
         json_file_name_model = json_path_model + '/' + get.model_type(model_name) + '-' + get.trial_num_json(csv_path_visual, 'csv') + '.json'
         json_file_name_visual = json_path_visual + '/' + get.model_type(model_name) + '-visual-' + get.trial_num_json(csv_path_visual, 'csv') + '.json'
-
+        json_file_name_shap = json_path_shap + '/' + get.model_type(model_name) + '-shap-' + get.trial_num_json(csv_path_visual, 'csv') + '.json'
 
 #         save_model_hdf5 = home + prefix_path + save_best_model + '/'  + 'trial-' + get.trial_num_json(csv_path_visual, 'csv')
 #         save_model_hdf5 = home + save_best_model + '/'
@@ -142,9 +139,11 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
                     'model_json': json_file_name_model,
                     'visual_csv': csv_file_name_visual,
                     'visual_json': json_file_name_visual,
+                    'shap_json': json_file_name_shap,
                     'model_json_full': home + prefix_path + json_file_name_model,
                     'visual_csv_full': home + prefix_path + csv_file_name_visual,
-                    'visual_json_full': home + prefix_path + json_file_name_visual}
+                    'visual_json_full': home + prefix_path + json_file_name_visual,
+                    'shap_json_full': home + prefix_path + json_file_name_shap}
 
     # 기존 path로 변경
     os.chdir(original_path)
